import numpy as np


def binary_search(lst, search_item):
    lon = 0
    high = len(lst) - 1

    while lon <= high:
        middle = (lon + high) // 2
        guess = lst[middle]
        if guess == search_item:
            return True

        if guess > search_item:
            high = middle - 1
        else:
            lon = middle + 1
    return False


while True:
    lst = input('Введите значения: ')
    lst = lst.split()
    value = input('Выберите элемент: ')

    array = np.array(lst)

    result = binary_search(array, value)
    if result:
        print(*np.where(array == value)[0])
    else:
        print(None)

    while end := input('Для завершения программы введите 1. Для продолжения введите 2: '):
        if end == '1' or end == '2':
            break
    if end == '1':
        break




from os import path
from setuptools import setup

try:
    current_path = path.abspath(path.dirname(__file__))
except NameError:
    current_path = None

try:
    with open(path.join(current_path, 'README.md'), encoding='utf-8') as f:
        long_description = f.read()
except FileNotFoundError:
    long_description = ''


setup(
    name="package219038924",
    version="0.0.1",
    author="Averyanova_Margarita",
    author_email="margaritaaveryanova2004@gmail.com",
    description='binary search',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=['package']
)
